# vialink-utils-logs



## Install Package

```
pip install vialink-utils-logs
```

## Using library

```
from vialink.utils import logs

logs.save(log_stream_name="custom-name", log_message="my message need to be string!")
```
